import * as i0 from '@angular/core';
import { InjectionToken, Injectable, Inject, Component, Input, NgModule } from '@angular/core';
import * as i2 from '@angular/common';
import { DOCUMENT, CommonModule } from '@angular/common';
import { of, fromEvent, BehaviorSubject } from 'rxjs';
import { filter, map, startWith } from 'rxjs/operators';
import { FormsModule } from '@angular/forms';

/**
 * A function that loads the saved theme.
 * Defaults to loading from local storage with the key `theme`.
 */
const THEME_LOADER = new InjectionToken('', {
    factory() {
        return () => {
            if (typeof window === 'undefined' || typeof localStorage === 'undefined') {
                return of(null);
            }
            return fromEvent(window, 'storage').pipe(filter(event => event.key === 'theme' && event.storageArea === localStorage), map(event => event.newValue), startWith(localStorage.getItem('theme')));
        };
    },
});
/**
 * A function that saves the theme.
 * Defaults to saving to local storage with the key `theme`.
 */
const THEME_SAVER = new InjectionToken('', {
    factory() {
        return theme => {
            if (typeof localStorage === 'undefined') {
                return;
            }
            if (theme) {
                localStorage.setItem('theme', theme);
            }
            else {
                localStorage.removeItem('theme');
            }
        };
    },
});
class ThemeService {
    constructor(document, loadHandler, saveHandler) {
        this._theme = new BehaviorSubject(null);
        (loadHandler()).subscribe(theme => this._theme.next(theme));
        this._theme.subscribe(theme => {
            if (theme) {
                document.body.setAttribute('data-theme', theme);
            }
            else {
                document.body.removeAttribute('data-theme');
            }
            saveHandler(theme);
        });
    }
    /**
     * @return a subject representing the currently active theme
     */
    get theme$() {
        return this._theme;
    }
    /**
     * @return `dark` if the user agent prefers dark color scheme, `light` otherwise
     */
    get detectedTheme() {
        return typeof window !== 'undefined' && window.matchMedia('(prefers-color-scheme: dark)').matches ? 'dark' : 'light';
    }
    /**
     * @return an observable version of {@link detectedTheme} that automatically updates on changes, e.g. when the user
     * changes their operating system theme preference, or it switches depending on day/night.
     */
    get detectedTheme$() {
        if (typeof window === 'undefined') {
            return of('light');
        }
        const mediaQuery = window.matchMedia('(prefers-color-scheme: dark)');
        return fromEvent(mediaQuery, 'change').pipe(map(event => event.matches), startWith(mediaQuery.matches), map(matches => matches ? 'dark' : 'light'));
    }
    /**
     * @return the current theme
     */
    get theme() {
        return this._theme.getValue();
    }
    /**
     * @param value
     *  the new theme
     */
    set theme(value) {
        this._theme.next(value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: ThemeService, deps: [{ token: DOCUMENT }, { token: THEME_LOADER }, { token: THEME_SAVER }], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: ThemeService, providedIn: 'root' }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: ThemeService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root',
                }]
        }], ctorParameters: () => [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [THEME_LOADER]
                }] }, { type: undefined, decorators: [{
                    type: Inject,
                    args: [THEME_SAVER]
                }] }] });

var Sizes;
(function (Sizes) {
    Sizes["sm"] = "sm";
    Sizes["md"] = "md";
    Sizes["lg"] = "lg";
})(Sizes || (Sizes = {}));
var Styles;
(function (Styles) {
    Styles["icon"] = "icon";
    Styles["label"] = "label";
})(Styles || (Styles = {}));
/**
 * A tri-state toggle button for switching between `light`, `auto` and `dark` theme.
 * Size and style (icon vs label) are configurable.
 */
class ThemeSwitchComponent {
    constructor(themeService) {
        this.themeService = themeService;
        /**
         * The size of the toggle button.
         *
         * - `sm` and `lg` translate to Bootstrap's `.btn-sm` and `.btn-lg`, respectively.
         * - `md` is the default and translates to just `.btn`.
         *
         * @see https://getbootstrap.com/docs/5.2/components/buttons/#sizes
         */
        this.size = Sizes.md;
        /**
         * The style of the button labels.
         *
         * - `icon` is the default and displays the Octicons for sun (light mode), telescope (auto mode) and moon (dark mode),
         * while also adding invisible text for screen readers.
         * - `label` uses textual labels instead (Light, Auto, Dark).
         *
         * @see https://primer.style/octicons/sun-16
         * @see https://primer.style/octicons/telescope-16
         * @see https://primer.style/octicons/moon-16
         */
        this.style = null;
    }
    ngOnInit() {
        this.theme$ = this.themeService.theme$;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: ThemeSwitchComponent, deps: [{ token: ThemeService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "18.2.6", type: ThemeSwitchComponent, selector: "olt-ngbd-theme-switch", inputs: { size: "size", style: "style" }, ngImport: i0, template: "<div class=\"btn-group btn-group-toggle\" [class.btn-group-sm]=\"size==='sm'\" [class.btn-group-lg]=\"size==='lg'\">\r\n  <button type=\"button\" class=\"btn btn-light\" (click)=\"theme$.next('light')\"\r\n    [class.active]=\"(theme$ | async) === 'light'\">\r\n    <!-- https://primer.style/octicons/sun-16 -->\r\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\"\r\n      fill=\"black\">\r\n      <path fill-rule=\"evenodd\"\r\n        d=\"M8 10.5a2.5 2.5 0 100-5 2.5 2.5 0 000 5zM8 12a4 4 0 100-8 4 4 0 000 8zM8 0a.75.75 0 01.75.75v1.5a.75.75 0 01-1.5 0V.75A.75.75 0 018 0zm0 13a.75.75 0 01.75.75v1.5a.75.75 0 01-1.5 0v-1.5A.75.75 0 018 13zM2.343 2.343a.75.75 0 011.061 0l1.06 1.061a.75.75 0 01-1.06 1.06l-1.06-1.06a.75.75 0 010-1.06zm9.193 9.193a.75.75 0 011.06 0l1.061 1.06a.75.75 0 01-1.06 1.061l-1.061-1.06a.75.75 0 010-1.061zM16 8a.75.75 0 01-.75.75h-1.5a.75.75 0 010-1.5h1.5A.75.75 0 0116 8zM3 8a.75.75 0 01-.75.75H.75a.75.75 0 010-1.5h1.5A.75.75 0 013 8zm10.657-5.657a.75.75 0 010 1.061l-1.061 1.06a.75.75 0 11-1.06-1.06l1.06-1.06a.75.75 0 011.06 0zm-9.193 9.193a.75.75 0 010 1.06l-1.06 1.061a.75.75 0 11-1.061-1.06l1.06-1.061a.75.75 0 011.061 0z\">\r\n      </path>\r\n    </svg>\r\n    <span [class.visually-hidden]=\"style !== 'label'\" [class.sr-only]=\"style !== 'label'\">Light</span>\r\n  </button>\r\n  <button type=\"button\" class=\"btn btn-secondary\" (click)=\"theme$.next('auto')\">\r\n    <!-- https://primer.style/octicons/telescope-16 -->\r\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\"\r\n      fill=\"white\">\r\n      <path fill-rule=\"evenodd\"\r\n        d=\"M14.184 1.143a1.75 1.75 0 00-2.502-.57L.912 7.916a1.75 1.75 0 00-.53 2.32l.447.775a1.75 1.75 0 002.275.702l11.745-5.656a1.75 1.75 0 00.757-2.451l-1.422-2.464zm-1.657.669a.25.25 0 01.358.081l1.422 2.464a.25.25 0 01-.108.35l-2.016.97-1.505-2.605 1.85-1.26zM9.436 3.92l1.391 2.41-5.42 2.61-.942-1.63 4.97-3.39zM3.222 8.157l-1.466 1a.25.25 0 00-.075.33l.447.775a.25.25 0 00.325.1l1.598-.769-.83-1.436zm6.253 2.306a.75.75 0 00-.944-.252l-1.809.87a.75.75 0 00-.293.253L4.38 14.326a.75.75 0 101.238.848l1.881-2.75v2.826a.75.75 0 001.5 0v-2.826l1.881 2.75a.75.75 0 001.238-.848l-2.644-3.863z\">\r\n      </path>\r\n    </svg>\r\n    <span [class.visually-hidden]=\"style !== 'label'\" [class.sr-only]=\"style !== 'label'\">Auto</span>\r\n  </button>\r\n  <button type=\"button\" class=\"btn btn-dark\" (click)=\"theme$.next('dark')\" [class.active]=\"(theme$ | async) === 'dark'\">\r\n    <!-- https://primer.style/octicons/moon-16 -->\r\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\"\r\n      fill=\"white\">\r\n      <path fill-rule=\"evenodd\"\r\n        d=\"M9.598 1.591a.75.75 0 01.785-.175 7 7 0 11-8.967 8.967.75.75 0 01.961-.96 5.5 5.5 0 007.046-7.046.75.75 0 01.175-.786zm1.616 1.945a7 7 0 01-7.678 7.678 5.5 5.5 0 107.678-7.678z\">\r\n      </path>\r\n    </svg>\r\n    <span [class.visually-hidden]=\"style !== 'label'\" [class.sr-only]=\"style !== 'label'\">Dark</span>\r\n  </button>\r\n</div>\r\n", styles: [""], dependencies: [{ kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "pipe", type: i2.AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: ThemeSwitchComponent, decorators: [{
            type: Component,
            args: [{ selector: 'olt-ngbd-theme-switch', template: "<div class=\"btn-group btn-group-toggle\" [class.btn-group-sm]=\"size==='sm'\" [class.btn-group-lg]=\"size==='lg'\">\r\n  <button type=\"button\" class=\"btn btn-light\" (click)=\"theme$.next('light')\"\r\n    [class.active]=\"(theme$ | async) === 'light'\">\r\n    <!-- https://primer.style/octicons/sun-16 -->\r\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\"\r\n      fill=\"black\">\r\n      <path fill-rule=\"evenodd\"\r\n        d=\"M8 10.5a2.5 2.5 0 100-5 2.5 2.5 0 000 5zM8 12a4 4 0 100-8 4 4 0 000 8zM8 0a.75.75 0 01.75.75v1.5a.75.75 0 01-1.5 0V.75A.75.75 0 018 0zm0 13a.75.75 0 01.75.75v1.5a.75.75 0 01-1.5 0v-1.5A.75.75 0 018 13zM2.343 2.343a.75.75 0 011.061 0l1.06 1.061a.75.75 0 01-1.06 1.06l-1.06-1.06a.75.75 0 010-1.06zm9.193 9.193a.75.75 0 011.06 0l1.061 1.06a.75.75 0 01-1.06 1.061l-1.061-1.06a.75.75 0 010-1.061zM16 8a.75.75 0 01-.75.75h-1.5a.75.75 0 010-1.5h1.5A.75.75 0 0116 8zM3 8a.75.75 0 01-.75.75H.75a.75.75 0 010-1.5h1.5A.75.75 0 013 8zm10.657-5.657a.75.75 0 010 1.061l-1.061 1.06a.75.75 0 11-1.06-1.06l1.06-1.06a.75.75 0 011.06 0zm-9.193 9.193a.75.75 0 010 1.06l-1.06 1.061a.75.75 0 11-1.061-1.06l1.06-1.061a.75.75 0 011.061 0z\">\r\n      </path>\r\n    </svg>\r\n    <span [class.visually-hidden]=\"style !== 'label'\" [class.sr-only]=\"style !== 'label'\">Light</span>\r\n  </button>\r\n  <button type=\"button\" class=\"btn btn-secondary\" (click)=\"theme$.next('auto')\">\r\n    <!-- https://primer.style/octicons/telescope-16 -->\r\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\"\r\n      fill=\"white\">\r\n      <path fill-rule=\"evenodd\"\r\n        d=\"M14.184 1.143a1.75 1.75 0 00-2.502-.57L.912 7.916a1.75 1.75 0 00-.53 2.32l.447.775a1.75 1.75 0 002.275.702l11.745-5.656a1.75 1.75 0 00.757-2.451l-1.422-2.464zm-1.657.669a.25.25 0 01.358.081l1.422 2.464a.25.25 0 01-.108.35l-2.016.97-1.505-2.605 1.85-1.26zM9.436 3.92l1.391 2.41-5.42 2.61-.942-1.63 4.97-3.39zM3.222 8.157l-1.466 1a.25.25 0 00-.075.33l.447.775a.25.25 0 00.325.1l1.598-.769-.83-1.436zm6.253 2.306a.75.75 0 00-.944-.252l-1.809.87a.75.75 0 00-.293.253L4.38 14.326a.75.75 0 101.238.848l1.881-2.75v2.826a.75.75 0 001.5 0v-2.826l1.881 2.75a.75.75 0 001.238-.848l-2.644-3.863z\">\r\n      </path>\r\n    </svg>\r\n    <span [class.visually-hidden]=\"style !== 'label'\" [class.sr-only]=\"style !== 'label'\">Auto</span>\r\n  </button>\r\n  <button type=\"button\" class=\"btn btn-dark\" (click)=\"theme$.next('dark')\" [class.active]=\"(theme$ | async) === 'dark'\">\r\n    <!-- https://primer.style/octicons/moon-16 -->\r\n    <svg *ngIf=\"style !== 'label'\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 16 16\" width=\"16\" height=\"16\"\r\n      fill=\"white\">\r\n      <path fill-rule=\"evenodd\"\r\n        d=\"M9.598 1.591a.75.75 0 01.785-.175 7 7 0 11-8.967 8.967.75.75 0 01.961-.96 5.5 5.5 0 007.046-7.046.75.75 0 01.175-.786zm1.616 1.945a7 7 0 01-7.678 7.678 5.5 5.5 0 107.678-7.678z\">\r\n      </path>\r\n    </svg>\r\n    <span [class.visually-hidden]=\"style !== 'label'\" [class.sr-only]=\"style !== 'label'\">Dark</span>\r\n  </button>\r\n</div>\r\n" }]
        }], ctorParameters: () => [{ type: ThemeService }], propDecorators: { size: [{
                type: Input
            }], style: [{
                type: Input
            }] } });

class NgxBootstrapDarkmodeModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: NgxBootstrapDarkmodeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "18.2.6", ngImport: i0, type: NgxBootstrapDarkmodeModule, declarations: [ThemeSwitchComponent], imports: [CommonModule,
            FormsModule], exports: [ThemeSwitchComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: NgxBootstrapDarkmodeModule, imports: [CommonModule,
            FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.6", ngImport: i0, type: NgxBootstrapDarkmodeModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ThemeSwitchComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                    ],
                    exports: [
                        ThemeSwitchComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-bootstrap-darkmode
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxBootstrapDarkmodeModule, Sizes, Styles, THEME_LOADER, THEME_SAVER, ThemeService, ThemeSwitchComponent };
//# sourceMappingURL=outerlimitstech-ngx-bootstrap-darkmode.mjs.map
